#version 460

#include "/lib/settings.glsl"

layout(location = 0) out vec3 outColor0;

const float ambientOcclusionLevel = 1.0; // [0.0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0]

uniform sampler2D colortex0, depthtex0;

uniform float far, near;

in vec2 texCoord;

const float ambient = AMBIENT_LIGHT * 0.1;

float depth = texture(depthtex0, texCoord).r;

float linearDepth = 2.0 * near * far / (far + near - (2.0 * depth - 1.0) * (far - near));

#ifdef AUTOMATIC_EXPOSURE
	in float autoExposure;
#endif

#include "/lib/post_processing.glsl"

#if FOG_STRENGTH
	in float fogStrength;

	uniform vec3 fogColor, skyColor;
#endif

void main() {
	vec3 color = pow(texture(colortex0, texCoord).rgb, vec3(2.2));

	if (depth < 1.0) {
		#if AMBIENT_LIGHT != 10
			color *= AMBIENT_LIGHT * 0.1;
		#endif

		#if FOG_STRENGTH
			float fogDistance = clamp(pow(pow(distance(texCoord.x, 0.5), 2.0) * 100.0 + linearDepth, 4.0) * fogStrength * 0.25, 0.0, 1.0);
			color = mix(color, mix(fogColor, skyColor, fogDistance), fogDistance);
		#endif
	}

	#if RED != 100 || GREEN != 100 || BLUE != 100
		color *= vec3(RED, GREEN, BLUE) * 0.01;
	#endif

	color = vec3(1.0) - exp(-color * EXPOSURE);

	#ifdef AUTOMATIC_EXPOSURE
		color *= autoExposure;
	#endif

	#if HDR_OVEREXPOSED != 100 || HDR_UNDEREXPOSED != 100
		color = mix(color * HDR_UNDEREXPOSED, color * HDR_OVEREXPOSED, color) * 0.01;
	#endif

	color = tonemap(color);

	outColor0 = color * (0.2 * color + 0.9);
}